"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createWcpGraphQL = void 0;
var _plugins = require("@webiny/handler-graphql/plugins");
var _responses = require("@webiny/handler-graphql/responses");
const emptyResolver = () => ({});
const createWcpGraphQL = () => {
  return new _plugins.GraphQLSchemaPlugin({
    typeDefs: /* GraphQL */`
            type WcpProjectPackageFeaturesFeature {
                enabled: Boolean
                options: JSON
            }

            type WcpProjectPackageFeatures {
                seats: WcpProjectPackageFeaturesFeature
                multiTenancy: WcpProjectPackageFeaturesFeature
                advancedPublishingWorkflow: WcpProjectPackageFeaturesFeature
                advancedAccessControlLayer: WcpProjectPackageFeaturesFeature
                auditLogs: WcpProjectPackageFeaturesFeature
                recordLocking: WcpProjectPackageFeaturesFeature
                fileManager: WcpProjectPackageFeaturesFeature
            }

            type WcpProjectPackage {
                features: WcpProjectPackageFeatures
            }

            type WcpProject {
                orgId: ID
                projectId: ID
                package: WcpProjectPackage
            }

            type WcpError {
                code: String
                message: String
                data: JSON
                stack: String
            }

            type WcpProjectResponse {
                data: WcpProject
                error: WcpError
            }

            type WcpQuery {
                getProject: WcpProjectResponse
            }

            type WcpMutation {
                updateProject: WcpProjectResponse
            }

            extend type Query {
                wcp: WcpQuery
            }

            extend type Mutation {
                wcp: WcpMutation
            }
        `,
    resolvers: {
      Query: {
        wcp: emptyResolver
      },
      WcpQuery: {
        getProject: (_, __, context) => {
          try {
            return new _responses.Response(context.wcp.getProject());
          } catch (e) {
            return new _responses.ErrorResponse({
              code: "COULD_NOT_GET_PROJECT",
              message: e.message,
              data: null,
              stack: e.stack
            });
          }
        }
      }
    }
  });
};
exports.createWcpGraphQL = createWcpGraphQL;

//# sourceMappingURL=graphql.js.map